# MapAttributesQuestionLoginInfo

The information about the user collected from the authentication system used to build the attribute mapping. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_object** | [**UserSummary**](UserSummary.md) |  | 
**client_guid** | **str** | The guid of the client initiating the request on behalf of the user | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


